#!/usr/bin/env python
# -*- mode: python; coding: utf-8; -*-
# ---------------------------------------------------------------------------##
#
# Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
# Copyright (C) 2003 Mt. Hood Playing Card Co.
# Copyright (C) 2005-2009 Skomoroh
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ---------------------------------------------------------------------------##
from . import cribbage  # noqa: F401
from . import dashavatara  # noqa: F401
from . import hanafuda  # noqa: F401
from . import hanafuda1  # noqa: F401
from . import hanoi  # noqa: F401
from . import hexadeck  # noqa: F401
from . import ishido  # noqa: F401
from . import larasgame  # noqa: F401
from . import lightsout  # noqa: F401
from . import matrix  # noqa: F401
from . import memory  # noqa: F401
from . import mughal  # noqa: F401
from . import pegged  # noqa: F401
from . import poker  # noqa: F401
from . import samegame  # noqa: F401
from . import tarock  # noqa: F401
from . import tarock1  # noqa: F401
from . import tilepuzzle  # noqa: F401


def no_use():
    pass
